pub struct RawResource {
pub ptr: *const u8,
pub len: usize,
}Expand description
A zero-copy buffer resource representing “Hilirisasi Data” (Downstreaming Data).
This struct holds a raw pointer to data that is NOT owned by this struct in the traditional sense (or rather, ownership is manually managed).
Fields
ptr: *const u8len: usizeImplementations